embassy-rp

Crates

git

Versions

rp235xa

Flavors

PioStepDir

Struct PioStepDir 

pub struct PioStepDir<'d, T: Instance, const SM: usize> { /* private fields */ }
PIO-backed Step/Dir stepper pulse generator.

One pin is driven by PIO for STEP pulses, and one GPIO pin is controlled by software for DIR.

Implementations

Source

impl<'d, T: Instance, const SM: usize> PioStepDir<'d, T, SM>

pub fn new( pio: &mut Common<'d, T>, sm: StateMachine<'d, T, SM>, irq: Irq<'d, T, SM>, step_pin: Peri<'d, impl PioPin>, dir_pin: Peri<'d, impl GpioPin>, program: &PioStepDirProgram<'d, T>, ) -> Self

Configure a state machine to generate STEP pulses and bind a DIR pin.

pub fn min_frequency(&self) -> u32

Return the minimum supported pulse frequency in Hz for this program.

pub fn set_frequency( &mut self, freq_hz: u32, ) -> Result<(), StepDirFrequencyError>

Set output pulse frequency in Hz.

pub fn frequency(&self) -> u32

Get the currently configured pulse frequency in Hz.

pub fn set_direction(&mut self, direction: StepDir)

Set motion direction.

pub async fn move_with_dir(&mut self, steps: u32, direction: StepDir)

Generate an exact number of STEP pulses in the given direction and wait until completion.

pub async fn move_steps(&mut self, steps: u32)

Generate an exact number of STEP pulses and wait until completion.

If this future is dropped before completion (e.g. cancelled via select!), the PIO state machine is automatically reset and the STEP pin is driven low.

pub fn stop(&mut self)

Stop pulse generation immediately and clear the state machine FIFOs.

pub fn release( self, ) -> (Irq<'d, T, SM>, StateMachine<'d, T, SM>, PioPinHandle<'d, T>, Output<'d>)

Release owned resources.